Documentation
¶
Overview ¶
Package repl is an interactive evaluator for Writ source.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type REPL ¶
type REPL struct {
In io.Reader
Out io.Writer
Err io.Writer
RT *writ.Runtime
// HistoryFile is the readline history path. Empty uses the user
// config directory. Readline is used only when In is a terminal.
HistoryFile string
}
REPL evaluates forms from In until EOF or the context is cancelled.
Click to show internal directories.
Click to hide internal directories.